@@ -1,7 +1,12 @@
 #!/usr/bin/env python3
 
+import sys, pytest
 import parametrize_from_file as pff
 
+pytest.mark.python38 = pytest.mark.skipif(
+        sys.version_info < (3, 8),
+        reason="python3.8 required",
+)
 with_repr = pff.Namespace('import reprfunc', 'from reprfunc import *')
 
 def get_obj(d):
@@ -12,7 +17,7 @@ def get_obj(d):
 
 
 @pff.parametrize
-def test_repr(obj, expected):
+def test_repr(obj, expected, request):
     obj = with_repr.exec(obj, get=get_obj)
     assert repr(obj) == expected
 
